@@ -57,6 +57,16 @@ class MQTT():
         cfg_str = f"\tCFG\t{dashboard_id}\t{self.cntrl_type}\t" + json.dumps(self._cfg) + "\n"
         return cfg_str
 
+    def get_cfg64(self, data) -> dict:
+        """Returns the CFG dict for this TCP control
+
+        Returns
+        -------
+        dict
+            The CFG string for this control
+        """
+        return self._cfg
+
     def __init__(self, control_id: str, username="", password="", servername="", use_ssl=False):
         self._cfg = {}
         self.cntrl_type = "MQTT"
